@@ -11,11 +11,9 @@
 #include <QObject>
 #include <QUrl>
 #include <QString>
-#include <QDir>
-#include <QFileInfo>
 
 
-#include <QtTest>
+#include <QTest>
 
 class ElisaApplicationTests: public QObject
 {
