@@ -39,7 +39,8 @@ public:
         V13 = 13,
         V14 = 14,
         V15 = 15,
-        V16 = 16, //Does not exist yet, for testing purpose only.
+        V16 = 16,
+        V17 = 17,
     };
 
     explicit DatabaseInterface(QObject *parent = nullptr);
@@ -150,31 +151,83 @@ public Q_SLOTS:
 
     void trackHasStartedPlaying(const QUrl &fileName, const QDateTime &time);
 
-    void clearData();
+    void trackHasFinishedPlaying(const QUrl &fileName, const QDateTime &time);
 
-    void insertRadio(const DataTypes::TrackDataType &oneTrack);
+    void clearData();
 
     void removeRadio(qulonglong radioId);
 
 private:
 
-    enum class TrackFileInsertType {
-        NewTrackFileInsert,
-        ModifiedTrackFileInsert,
+    enum class DatabaseState {
+        GoodState,
+        BadState,
     };
 
+    /********* Init and upgrade methods *********/
+
+    void initConnection(const QString &connectionName, const QString &databaseFileName);
+
+    bool initDatabase();
+
+    void createDatabaseV9();
+
+    void upgradeDatabaseV9();
+
+    void upgradeDatabaseV11();
+
+    void upgradeDatabaseV12();
+
+    void upgradeDatabaseV13();
+
+    void upgradeDatabaseV14();
+
+    void upgradeDatabaseV15();
+
+    void upgradeDatabaseV16();
+
+    void upgradeDatabaseV17();
+
+    [[nodiscard]] DatabaseState checkDatabaseSchema() const;
+
+    [[nodiscard]] DatabaseState checkTable(const QString &tableName, const QStringList &expectedColumns) const;
+
+    bool resetDatabase();
+
+    DatabaseVersion currentDatabaseVersion();
+
+    bool upgradeDatabaseToLatestVersion();
+
+    void dropTable(const QString &table);
+
+    void setDatabaseVersionInTable(int version);
+
+    void createDatabaseVersionTable();
+
+    void initDatabaseVersionQueries();
+
+    void callUpgradeFunctionForVersion(DatabaseVersion databaseVersion);
+
+    /********* Data query methods *********/
+
+    bool startTransaction();
+
+    bool finishTransaction();
+
+    bool rollBackTransaction();
+
+    bool prepareQuery(QSqlQuery &query, const QString &queryText) const;
+
+    bool execQuery(QSqlQuery &query);
+
+    void initDataQueries();
+
     void initChangesTrackers();
 
     void recordModifiedTrack(qulonglong trackId);
 
     void recordModifiedAlbum(qulonglong albumId);
 
-    bool startTransaction() const;
-
-    bool finishTransaction() const;
-
-    bool rollBackTransaction() const;
-
     QList<qulonglong> fetchTrackIds(qulonglong albumId);
 
     qulonglong internalAlbumIdFromTitleAndArtist(const QString &title, const QString &artist, const QString &albumPath);
@@ -198,10 +251,6 @@ private:
 
     QList<qulonglong> internalAlbumIdsFromAuthor(const QString &artistName);
 
-    void initDatabase();
-
-    void initRequest();
-
     qulonglong insertAlbum(const QString &title, const QString &albumArtist,
                            const QString &trackPath, const QUrl &albumArtURI);
 
@@ -233,9 +282,9 @@ private:
     qulonglong internalInsertTrack(const DataTypes::TrackDataType &oneModifiedTrack,
                                    const QHash<QString, QUrl> &covers, bool &isInserted);
 
-    DataTypes::TrackDataType buildTrackDataFromDatabaseRecord(const QSqlRecord &trackRecord) const;
+    [[nodiscard]] DataTypes::TrackDataType buildTrackDataFromDatabaseRecord(const QSqlRecord &trackRecord) const;
 
-    DataTypes::TrackDataType buildRadioDataFromDatabaseRecord(const QSqlRecord &trackRecord) const;
+    [[nodiscard]] DataTypes::TrackDataType buildRadioDataFromDatabaseRecord(const QSqlRecord &trackRecord) const;
 
     void internalRemoveTracksList(const QList<QUrl> &removedTracks);
 
@@ -257,6 +306,8 @@ private:
 
     DataTypes::ListAlbumDataType internalAllAlbumsPartialData(QSqlQuery &query);
 
+    DataTypes::ListTrackDataType internalOneAlbumData(qulonglong databaseId);
+
     DataTypes::AlbumDataType internalOneAlbumPartialData(qulonglong databaseId);
 
     DataTypes::ArtistDataType internalOneArtistPartialData(qulonglong databaseId);
@@ -281,62 +332,20 @@ private:
 
     DataTypes::ListArtistDataType internalAllLyricistsPartialData();
 
-    bool prepareQuery(QSqlQuery &query, const QString &queryText) const;
-
-    bool execQuery(QSqlQuery &query);
-
     void updateAlbumArtist(qulonglong albumId, const QString &title, const QString &albumPath,
                            const QString &artistName);
 
-    void updateTrackStatistics(const QUrl &fileName, const QDateTime &time);
+    bool updateAlbumCover(qulonglong albumId, const QUrl &albumArtUri);
 
-    void createDatabaseV9();
+    QVariantList internalGetLatestFourCoversForArtist(const QString& artistName);
 
-    void upgradeDatabaseV9();
+    void updateTrackStartedStatistics(const QUrl &fileName, const QDateTime &time);
 
-    void upgradeDatabaseV11();
+    void updateTrackFinishedStatistics(const QUrl &fileName, const QDateTime &time);
 
-    void upgradeDatabaseV12();
+    void internalInsertOneTrack(const DataTypes::TrackDataType &oneTrack, const QHash<QString, QUrl> &covers);
 
-    void upgradeDatabaseV13();
-
-    void upgradeDatabaseV14();
-
-    void upgradeDatabaseV15();
-
-    void upgradeDatabaseV16();
-
-    void checkDatabaseSchema();
-
-    void checkAlbumsTableSchema();
-
-    void checkArtistsTableSchema();
-
-    void checkComposerTableSchema();
-
-    void checkGenreTableSchema();
-
-    void checkLyricistTableSchema();
-
-    void checkTracksTableSchema();
-
-    void checkTracksDataTableSchema();
-
-    void genericCheckTable(const QString &tableName, const QStringList &expectedColumns);
-
-    void resetDatabase();
-
-    void manageNewDatabaseVersion();
-
-    void dropTable(const QString &table);
-
-    void setDatabaseVersionInTable(int version);
-
-    void createDatabaseVersionTable();
-
-    void manageNewDatabaseVersionInitRequests();
-
-    void callUpgradeFunctionForVersion(DatabaseVersion databaseVersion);
+    void internalInsertOneRadio(const DataTypes::TrackDataType &oneTrack);
 
     std::unique_ptr<DatabaseInterfacePrivate> d;
 
