@@ -75,7 +75,6 @@ void ElisaConfigurationDialog::save()
     Elisa::ElisaConfiguration::setShowNowPlayingBackground(mShowNowPlayingBackground);
     Elisa::ElisaConfiguration::setShowProgressOnTaskBar(mShowProgressInTaskBar);
     Elisa::ElisaConfiguration::setShowSystemTrayIcon(mShowSystemTrayIcon);
-    Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(!mForceUsageOfSlowFileSystemIndexing);
     Elisa::ElisaConfiguration::setAlwaysUseAbsolutePlaylistPaths(mAlwaysUseAbsolutePlaylistPaths);
     Elisa::ElisaConfiguration::setPlayAtStartup(mPlayAtStartup);
     Elisa::ElisaConfiguration::setScanAtStartup(mScanAtStartup);
@@ -162,18 +161,6 @@ void ElisaConfigurationDialog::setShowSystemTrayIcon(bool showSystemTrayIcon)
     setDirty();
 }
 
-void ElisaConfigurationDialog::setForceUsageOfSlowFileSystemIndexing(bool forceUsageOfSlowFileSystemIndexing)
-{
-    if (mForceUsageOfSlowFileSystemIndexing == forceUsageOfSlowFileSystemIndexing) {
-        return;
-    }
-
-    mForceUsageOfSlowFileSystemIndexing = forceUsageOfSlowFileSystemIndexing;
-    Q_EMIT forceUsageOfSlowFileSystemIndexingChanged();
-
-    setDirty();
-}
-
 void ElisaConfigurationDialog::setAlwaysUseAbsolutePlaylistPaths(bool alwaysUseAbsolutePlaylistPaths)
 {
     if (mAlwaysUseAbsolutePlaylistPaths == alwaysUseAbsolutePlaylistPaths) {
@@ -193,7 +180,7 @@ void ElisaConfigurationDialog::setEmbeddedView(ElisaUtils::PlayListEntryType emb
     }
 
     mEmbeddedView = embeddedView;
-    QTimer::singleShot(0, [this](){ Q_EMIT embeddedViewChanged(); });
+    QTimer::singleShot(0, this, &ElisaConfigurationDialog::embeddedViewChanged);
 
     setDirty();
 }
@@ -205,7 +192,7 @@ void ElisaConfigurationDialog::setInitialViewIndex(int initialViewIndex)
     }
 
     mInitialViewIndex = initialViewIndex;
-    QTimer::singleShot(0, [this](){ Q_EMIT initialViewIndexChanged(); });
+    QTimer::singleShot(0, this, &ElisaConfigurationDialog::initialViewIndexChanged);
 
     setDirty();
 }
@@ -298,9 +285,6 @@ void ElisaConfigurationDialog::configChanged()
     mUseFavoriteStyleRatings = Elisa::ElisaConfiguration::useFavoriteStyleRatings();
     Q_EMIT useFavoriteStyleRatingsChanged();
 
-    mForceUsageOfSlowFileSystemIndexing = !Elisa::ElisaConfiguration::forceUsageOfFastFileSearch();
-    Q_EMIT forceUsageOfSlowFileSystemIndexingChanged();
-
     mAlwaysUseAbsolutePlaylistPaths = Elisa::ElisaConfiguration::alwaysUseAbsolutePlaylistPaths();
     Q_EMIT alwaysUseAbsolutePlaylistPathsChanged();
 
