@@ -7,6 +7,7 @@
  */
 
 #include "mediaplaylistproxymodel.h"
+#include "elisautils.h"
 #include "mediaplaylist.h"
 #include "playListLogging.h"
 #include "elisa_settings.h"
@@ -19,7 +20,7 @@
 #include <QDir>
 #include <QMimeDatabase>
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
 #include <KIO/OpenUrlJob>
 #endif
 
@@ -351,10 +352,10 @@ MediaPlayListProxyModel::Repeat MediaPlayListProxyModel::repeatMode() const
 void MediaPlayListProxyModel::setShufflePlayList(const bool value)
 {
     if (d->mShufflePlayList != value) {
-        Q_EMIT layoutAboutToBeChanged(QList<QPersistentModelIndex>(), QAbstractItemModel::VerticalSortHint);
         auto playListSize = d->mPlayListModel->rowCount();
 
         if (playListSize != 0) {
+            Q_EMIT layoutAboutToBeChanged(QList<QPersistentModelIndex>(), QAbstractItemModel::VerticalSortHint);
             if (value) {
                 d->mRandomMapping.clear();
                 d->mRandomMapping.reserve(playListSize);
@@ -633,17 +634,19 @@ void MediaPlayListProxyModel::trackInError(const QUrl &sourceInError, QMediaPlay
     d->mPlayListModel->trackInError(sourceInError, playerError);
 }
 
-void MediaPlayListProxyModel::skipNextTrack()
+void MediaPlayListProxyModel::skipNextTrack(ElisaUtils::SkipReason reason /*= ElisaUtils::SkipReason::Automatic*/)
 {
     if (!d->mCurrentTrack.isValid()) {
         return;
     }
 
-    if (d->mCurrentTrack.row() >= rowCount() - 1) {
+    if (d->mRepeatMode == Repeat::One && reason == ElisaUtils::SkipReason::Automatic) {
+        // case 1: repeat current track
+        d->mCurrentTrack = index(d->mCurrentTrack.row(), 0);
+    } else if (d->mCurrentTrack.row() >= rowCount() - 1) {
+        // case 2: end of playlist, check if we loop back
         switch (d->mRepeatMode) {
         case Repeat::One:
-            d->mCurrentTrack = index(d->mCurrentTrack.row(), 0);
-            break;
         case Repeat::Playlist:
             d->mCurrentTrack = index(0, 0);
             break;
@@ -653,11 +656,8 @@ void MediaPlayListProxyModel::skipNextTrack()
             break;
         }
     } else {
-        if (d->mRepeatMode == Repeat::One) {
-            d->mCurrentTrack = index(d->mCurrentTrack.row(), 0);
-        } else {
-            d->mCurrentTrack = index(d->mCurrentTrack.row() + 1, 0);
-        }
+        // default case: start playing next track
+        d->mCurrentTrack = index(d->mCurrentTrack.row() + 1, 0);
     }
 
     notifyCurrentTrackChanged();
@@ -681,11 +681,7 @@ void MediaPlayListProxyModel::skipPreviousTrack(qint64 position)
             return;
         }
     } else {
-        if (d->mRepeatMode == Repeat::One) {
-            d->mCurrentTrack = index(d->mCurrentTrack.row(), 0);
-        } else {
-            d->mCurrentTrack = index(d->mCurrentTrack.row() - 1, 0);
-        }
+        d->mCurrentTrack = index(d->mCurrentTrack.row() - 1, 0);
     }
 
     notifyCurrentTrackChanged();
@@ -717,6 +713,9 @@ void MediaPlayListProxyModel::removeRow(int row)
 
 void MediaPlayListProxyModel::moveRow(int from, int to)
 {
+    const bool currentTrackIndexChanged = from < to ? (from <= d->mCurrentTrack.row() && d->mCurrentTrack.row() <= to)
+                                                    : (to <= d->mCurrentTrack.row() && d->mCurrentTrack.row() <= from);
+
     if (d->mShufflePlayList) {
         beginMoveRows({}, from, from, {}, from < to ? to + 1 : to);
         d->mRandomMapping.move(from, to);
@@ -724,9 +723,13 @@ void MediaPlayListProxyModel::moveRow(int from, int to)
     } else {
         d->mPlayListModel->moveRows({}, from, 1, {}, from < to ? to + 1 : to);
     }
+
+    if (currentTrackIndexChanged) {
+        notifyCurrentTrackRowChanged();
+    }
 }
 
-void MediaPlayListProxyModel::notifyCurrentTrackChanged()
+void MediaPlayListProxyModel::notifyCurrentTrackRowChanged()
 {
     if (d->mCurrentTrack.isValid()) {
         d->mCurrentPlayListPosition = d->mCurrentTrack.row();
@@ -734,11 +737,16 @@ void MediaPlayListProxyModel::notifyCurrentTrackChanged()
         d->mCurrentPlayListPosition = -1;
     }
     determineAndNotifyPreviousAndNextTracks();
-    Q_EMIT currentTrackChanged(d->mCurrentTrack);
     Q_EMIT currentTrackRowChanged();
     Q_EMIT remainingTracksChanged();
 }
 
+void MediaPlayListProxyModel::notifyCurrentTrackChanged()
+{
+    notifyCurrentTrackRowChanged();
+    Q_EMIT currentTrackChanged(d->mCurrentTrack);
+}
+
 void MediaPlayListProxyModel::determineAndNotifyPreviousAndNextTracks()
 {
     if (!d->mCurrentTrack.isValid()) {
@@ -787,6 +795,26 @@ void MediaPlayListProxyModel::determineAndNotifyPreviousAndNextTracks()
     }
 }
 
+int MediaPlayListProxyModel::indexForTrackUrl(const QUrl &url)
+{
+    for (int i = 0; i < rowCount(); ++i) {
+        const QUrl thisTrackUrl = data(index(i,0), MediaPlayList::ResourceRole).toUrl();
+        if (thisTrackUrl == url) {
+            return i;
+        }
+    }
+    return -1;
+}
+
+void MediaPlayListProxyModel::switchToTrackUrl(const QUrl &url, ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    switchTo(indexForTrackUrl(url));
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT requestPlay();
+    }
+}
+
 void MediaPlayListProxyModel::clearPlayList()
 {
     if (rowCount() == 0) {
@@ -850,18 +878,9 @@ bool MediaPlayListProxyModel::savePlayList(const QUrl &fileName)
             }
         }
     } else {
-        QFileInfo playlistFile(fileName.toLocalFile());
-        QDir dir(playlistFile.absolutePath());
-
         for (int i = 0; i < rowCount(); ++i) {
             if (data(index(i,0), MediaPlayList::IsValidRole).toBool()) {
-                QFileInfo musicFile(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
-
-                if (musicFile.dir().path() == dir.absolutePath()) {
-                    listOfFilePaths.append(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
-                } else {
-                    listOfFilePaths.append(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
-                }
+                listOfFilePaths.append(data(index(i,0), MediaPlayList::ResourceRole).toUrl().toLocalFile());
             }
         }
     }
@@ -966,7 +985,7 @@ bool MediaPlayListProxyModel::partiallyLoaded() const
 
 bool MediaPlayListProxyModel::canOpenLoadedPlaylist() const
 {
-#if !KF5KIO_FOUND
+#if !KFKIO_FOUND
     return false;
 #endif
     return d->mLoadedPlayListUrl.isValid() && d->mLoadedPlayListUrl.isLocalFile();
@@ -974,7 +993,7 @@ bool MediaPlayListProxyModel::canOpenLoadedPlaylist() const
 
 void MediaPlayListProxyModel::openLoadedPlayList()
 {
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
     auto job = new KIO::OpenUrlJob(d->mLoadedPlayListUrl, QLatin1String("text/plain"));
     job->start();
 #endif
@@ -1033,7 +1052,7 @@ void MediaPlayListProxyModel::loadLocalPlayList(DataTypes::EntryDataList &newTra
         d->mPartiallyLoaded = true;
     }
 
-    for (const QUrl &oneUrl : qAsConst(listOfUrls)) {
+    for (const QUrl &oneUrl : std::as_const(listOfUrls)) {
         if (oneUrl.isLocalFile()) {
             QFileInfo fileInfo(oneUrl.toLocalFile());
             loadLocalFile(newTracks, processedFiles, fileInfo);
